using System.IO;
using System.Security.Cryptography;
using Autofac;
using FitConnect.Encryption;
using FitConnect.Models;
using FluentAssertions;
using MockContainer;
using NUnit.Framework;

namespace SenderTest;

public class FileEncryptionTest {
    private string _encryptedFile;
    private FitEncryption _encryption;
    private byte[] sourceFile = null!;

    [SetUp]
    public void Setup() {
        sourceFile = RandomNumberGenerator.GetBytes(4096);
        var container = Container.Create();
        var keySet = container.Resolve<KeySet>();
        _encryption = new FitEncryption(keySet, null);
    }

    [Test]
    [Order(10)]
    public void EncryptFile() {
        _encryptedFile = _encryption.Encrypt(sourceFile);
    }

    [Test]
    public void TestSha512FileHash() {
        // Arrange
        var content = File.ReadAllBytes("Test.pdf");


        // Act
        var attachment = new Attachment("Test.pdf", "Just an attachment");

        var hash = attachment.Hash;
        // Assert
        hash.Should()
            .Be(
                "8b1042900c2039f65fe6c4cb1bca31e2a7a04b61d3ca7d9ae9fc4077068b82ad5512fa298385b025db70551113b762064444b87737e45e657a71be5b88b06e59");
    }
}
