// Root myDeserializedClass = JsonSerializer.Deserialize<Root>(myJsonResponse);

using Newtonsoft.Json;

namespace FitConnect.Services.Models.v1.Routes;

public class DestinationParameters {
    [JsonProperty("encryptionKid")]
    public string EncryptionKid { get; set; }

    [JsonProperty("metadataVersions")]
    public List<string> MetadataVersions { get; set; }

    [JsonProperty("publicKeys")]
    public PublicKeys PublicKeys { get; set; }

    [JsonProperty("replyChannels")]
    public ReplyChannels ReplyChannels { get; set; }

    [JsonProperty("status")]
    public string Status { get; set; }

    [JsonProperty("submissionSchemas")]
    public List<SubmissionSchema> SubmissionSchemas { get; set; }

    [JsonProperty("submissionUrl")]
    public string SubmissionUrl { get; set; }
}

public class EMail {
    [JsonProperty("usePgp")]
    public bool UsePgp { get; set; }
}

public class Key {
    [JsonProperty("kty")]
    public string Kty { get; set; }

    [JsonProperty("key_ops")]
    public List<string> KeyOps { get; set; }

    [JsonProperty("alg")]
    public string Alg { get; set; }

    [JsonProperty("x5c")]
    public List<string> X5c { get; set; }

    [JsonProperty("kid")]
    public string Kid { get; set; }

    [JsonProperty("n")]
    public string N { get; set; }

    [JsonProperty("e")]
    public string E { get; set; }

    public string ToString() {
        return JsonConvert.SerializeObject(this);
    }
}

public class PublicKeys {
    [JsonProperty("keys")]
    public List<Key> Keys { get; set; }
}

public class ReplyChannels {
    [JsonProperty("email")]
    public EMail EMail { get; set; }
}

public class RoutesListDto {
    [JsonProperty("count")]
    public int Count { get; set; }

    [JsonProperty("offset")]
    public int Offset { get; set; }

    [JsonProperty("totalCount")]
    public int TotalCount { get; set; }

    [JsonProperty("routes")]
    public List<Route> Routes { get; set; }
}

public class Route {
    [JsonProperty("destinationId")]
    public string DestinationId { get; set; }

    [JsonProperty("destinationSignature")]
    public string DestinationSignature { get; set; }

    [JsonProperty("destinationParameters")]
    public DestinationParameters DestinationParameters { get; set; }

    [JsonProperty("destinationParametersSignature")]
    public string DestinationParametersSignature { get; set; }

    [JsonProperty("destinationName")]
    public string DestinationName { get; set; }

    
    [System.Text.Json.Serialization.JsonIgnore]
    public string DestinationParameterString { get;set; }
}

public class SubmissionSchema {
    [JsonProperty("schemaUri")]
    public string SchemaUri { get; set; }

    [JsonProperty("mimeType")]
    public string MimeType { get; set; }
}
