using System;
using System.Net.Http;
using FitConnect.Models;
using FluentAssertions;
using NUnit.Framework;

namespace IntegrationTests.Sender;

[TestFixture]
public class SenderTestUnhappyPath : SenderTestBase {
    [Test]
    public void WithDestination_UnknownUUID_ShouldThrowAggregateWithInnerHttpRequestException() {
        Assert.Throws<AggregateException>(() => { Sender.WithDestination(Guid.Empty.ToString()); })
            .InnerExceptions.Should().ContainItemsAssignableTo<HttpRequestException>();
    }


    [Test]
    public void WithDestination_CompletelyWrong_ShouldThrowArgumentException() {
        Assert.Throws<ArgumentException>(() => { Sender.WithDestination("This is very wrong"); })
            .Message.Should().Be("The destination must be a valid GUID");
    }

    [Test]
    public void WithData_DataIsInvalidJson_ShouldThrowArgumentException() {
        Assert.Throws<ArgumentException>(() => {
                Sender.WithDestination(desitnationId)
                    .WithServiceType("Name", "urn:de:fim:leika:leistung:00000000000000")
                    .WithAttachments(new Attachment("Test.pdf", "Test PDF"))
                    .WithData("This is very wrong");
            })
            .Message.Should().Be("The data must be valid JSON string");
    }
}
