using System.Linq;
using FluentAssertions;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using NUnit.Framework;

namespace IntegrationTests.Subscriber;

[TestFixture]
public class SubscriberTestUnHappyPath : SubscriberTestBase {
    [Test]
    public void TestMetaData_InvalidData() {
        // Arrange
        var wrongData = "{\"name\":\"value\"}";

        // Act
        var validationErrors = FitConnect.Subscriber.VerifyMetadata(wrongData);
        validationErrors.ToList().ForEach(v => Logger?.LogWarning("ERROR: {V}", v.ToString()));

        // Assert
        validationErrors.Count.Should().BeGreaterThan(0);
    }

    [Test]
    public void TestMetaData_EmptyString() {
        // Arrange
        var wrongData = "";

        // Act && Assert
        Assert.Throws<JsonReaderException>(() => {
            var validationErrors = FitConnect.Subscriber.VerifyMetadata(wrongData);
            validationErrors.ToList().ForEach(v => Logger.LogWarning("ERROR: {V}", v.ToString()));
        });
    }
}
